# -*- coding: utf-8 -*-
# -*- mode: python -*-
"""
arfx is a tool for copying data to and from ARF files. It is intended for simple
operations involving single channel datasets, though it can also be used to copy
entire entries between ARF files.
"""

__version__ = "2.6.9"
